/*
This file is part of uvcc -- USB Video Class (UVC) device configurator.
Copyright (C) 2018, 2019, 2020, 2021, 2022 Joel Purra <https://joelpurra.com/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <https://www.gnu.org/licenses/>.
*/
import assert from "node:assert";
export default class CameraHelperFactory {
    constructor(output, cameraControlHelperFactory, 
    // eslint-disable-next-line @typescript-eslint/naming-convention
    CameraHelper) {
        Object.defineProperty(this, "output", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: output
        });
        Object.defineProperty(this, "cameraControlHelperFactory", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: cameraControlHelperFactory
        });
        Object.defineProperty(this, "CameraHelper", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: CameraHelper
        });
        assert.strictEqual(arguments.length, 3);
        assert(typeof this.output === "object");
        assert(typeof this.cameraControlHelperFactory === "object");
        assert(typeof this.CameraHelper === "function");
    }
    async get(camera) {
        assert.strictEqual(arguments.length, 1);
        assert(typeof camera === "object");
        const cameraControlHelper = await this.cameraControlHelperFactory.get(camera);
        const cameraHelper = new this.CameraHelper(this.output, cameraControlHelper, camera);
        return cameraHelper;
    }
}
