/*
This file is part of uvcc -- USB Video Class (UVC) device configurator.
Copyright (C) 2018, 2019, 2020, 2021, 2022 Joel Purra <https://joelpurra.com/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <https://www.gnu.org/licenses/>.
*/
import assert from "node:assert";
export default class CommandHandlers {
    constructor(output, commands) {
        Object.defineProperty(this, "output", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: output
        });
        Object.defineProperty(this, "commands", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: commands
        });
        assert.strictEqual(arguments.length, 2);
        assert(typeof this.output === "object");
        assert(typeof this.commands === "object");
    }
    async has(commandName) {
        assert.strictEqual(arguments.length, 1);
        assert(typeof commandName === "string");
        const command = this.commands[commandName];
        return Boolean(command);
    }
    async execute(commandName, ...args) {
        assert(typeof commandName === "string");
        assert(Array.isArray(args));
        const command = this.commands[commandName];
        assert(typeof command === "object");
        const output = await command.execute(...args);
        return output;
    }
    async getArguments(commandName) {
        assert.strictEqual(arguments.length, 1);
        assert(typeof commandName === "string");
        const command = this.commands[commandName];
        assert(typeof command === "object");
        return command.getArguments();
    }
}
